@@ -1,114 +1,36 @@
-/*
- * Copyright (c) 1995-2001, Index Data.
+/* This file is part of the YAZ toolkit.
+ * Copyright (C) 1995-2009 Index Data.
+ * All rights reserved.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * Permission to use, copy, modify, distribute, and sell this software and
- * its documentation, in whole or in part, for any purpose, is hereby granted,
- * provided that:
+ *     * Redistributions of source code must retain the above copyright
+ *       notice, this list of conditions and the following disclaimer.
+ *     * Redistributions in binary form must reproduce the above copyright
+ *       notice, this list of conditions and the following disclaimer in the
+ *       documentation and/or other materials provided with the distribution.
+ *     * Neither the name of Index Data nor the names of its contributors
+ *       may be used to endorse or promote products derived from this
+ *       software without specific prior written permission.
  *
- * 1. This copyright and permission notice appear in all copies of the
- * software and its documentation. Notices of copyright or attribution
- * which appear at the beginning of any file must remain unchanged.
- *
- * 2. The name of Index Data or the individual authors may not be used to
- * endorse or promote products derived from this software without specific
- * prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY OF ANY KIND,
- * EXPRESS, IMPLIED, OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY
- * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
- * IN NO EVENT SHALL INDEX DATA BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
- * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES
- * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR
- * NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF
- * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE
- * OF THIS SOFTWARE.
- *
- * $Log: backend.h,v $
- * Revision 1.14  2002/03/20 14:36:00  adam
- * Additional Search Info for GFS
- *
- * Revision 1.13  2002/03/05 12:45:49  mike
- * Add trivial support for implementation_id specified by backend.
- *
- * Revision 1.12  2001/03/25 21:55:12  adam
- * Added odr_intdup. Ztest server returns TaskPackage for ItemUpdate.
- *
- * Revision 1.11  2001/01/30 21:34:17  adam
- * Added step-size for Scan backend interface.
- *
- * Revision 1.10  2000/10/02 11:07:44  adam
- * Added peer_name member for bend_init handler. Changed the YAZ
- * client so that tcp: can be avoided in target spec.
- *
- * Revision 1.9  2000/08/31 10:20:12  adam
- * Added member request_format and output_format for backend fetch method.
- *
- * Revision 1.8  2000/08/31 09:51:25  adam
- * Added record_syntax member for fetch method (raw OID).
- *
- * Revision 1.7  2000/04/05 07:39:55  adam
- * Added shared library support (libtool).
- *
- * Revision 1.6  2000/03/20 19:06:25  adam
- * Added Segment request for fronend server. Work on admin for client.
- *
- * Revision 1.5  2000/03/15 12:59:49  adam
- * Added handle member to statserv_control.
- *
- * Revision 1.4  2000/02/28 11:20:06  adam
- * Using autoconf. New definitions: YAZ_BEGIN_CDECL/YAZ_END_CDECL.
- *
- * Revision 1.3  2000/01/12 14:36:07  adam
- * Added printing stream (ODR) for backend functions.
- *
- * Revision 1.2  1999/12/16 23:36:19  adam
- * Implemented ILL protocol. Minor updates ASN.1 compiler.
- *
- * Revision 1.1  1999/11/30 13:47:11  adam
- * Improved installation. Moved header files to include/yaz.
- *
- * Revision 1.28  1999/11/04 14:58:44  adam
- * Added status elements for backend delete result set handler.
- * Updated delete result result set command for client.
- *
- * Revision 1.27  1999/10/11 10:01:24  adam
- * Implemented bend_sort_rr handler for frontend server.
- *
- * Revision 1.26  1999/06/17 10:54:44  adam
- * Added facility to specify implementation version - and name
- * for server.
- *
- * Revision 1.25  1999/06/01 14:29:12  adam
- * Work on Extended Services.
- *
- * Revision 1.24  1999/03/31 11:18:24  adam
- * Implemented odr_strdup. Added Reference ID to backend server API.
- *
- * Revision 1.23  1998/10/13 16:12:23  adam
- * Added support for Surrogate Diagnostics for Scan Term entries.
- *
- * Revision 1.22  1998/09/02 12:41:51  adam
- * Added decode stream in bend search structures.
- *
- * Revision 1.21  1998/07/20 12:38:41  adam
- * Implemented delete result set service to server API.
- *
- * Revision 1.20  1998/05/27 16:57:06  adam
- * Support for surrogate diagnostic records added for bend_fetch.
- *
- * Revision 1.19  1998/03/31 11:07:45  adam
- * Furhter work on UNIverse resource report.
- * Added Extended Services handling in frontend server.
- *
- * Revision 1.18  1998/02/10 11:03:56  adam
- * Added support for extended handlers in backend server interface.
- *
- * Revision 1.17  1998/01/29 13:15:35  adam
- * Implemented sort for the backend interface.
- *
- * Revision 1.16  1997/09/17 12:10:31  adam
- * YAZ version 1.4.
+ * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
+ * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
+ * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+/** 
+ * \file backend.h
+ * \brief Header for GFS
  *
+ * This header includes all public definitions for the
+ * Generic Frontend Server (GFS).
  */
 
 #ifndef BACKEND_H
@@ -116,13 +38,15 @@
 
 #include <yaz/yconfig.h>
 #include <yaz/proto.h>
+#include <yaz/srw.h>
+#include <yaz/oid_db.h>
 
 YAZ_BEGIN_CDECL
     
 typedef struct request *bend_request;
 typedef struct association *bend_association;
 
-/* extended search handler (rr = request response) */
+/** \brief Information for Z39.50/SRU search handler */
 typedef struct {
     char *setname;             /* name to give to this set */
     int replace_set;           /* replace set, if it already exists */
@@ -137,18 +61,23 @@ typedef struct {
     bend_request request;
     bend_association association;
     int *fd;
-    int hits;                  /* number of hits */
+    Odr_int hits;                  /* number of hits */
     int errcode;               /* 0==OK */
     char *errstring;           /* system error string or NULL */
     Z_OtherInformation *search_info; /* additional search info */
+    char *srw_sortKeys;        /* holds SRU/SRW sortKeys info */
+    char *srw_setname;         /* holds SRU/SRW generated resultsetID */
+    int *srw_setnameIdleTime;  /* holds SRU/SRW life-time */
+    int estimated_hit_count;   /* if hit count is estimated */
+    int partial_resultset;     /* if result set is partial */
 } bend_search_rr;
 
-/* extended present handler. Does not replace bend_fetch. */
+/** \brief Information for present handler. Does not replace bend_fetch. */
 typedef struct {
     char *setname;             /* set name */
     int start;
     int number;                /* record number */
-    oid_value format;          /* One of the CLASS_RECSYN members */
+    Odr_oid *format;           /* format, transfer syntax (OID) */
     Z_ReferenceId *referenceId;/* reference ID */
     Z_RecordComposition *comp; /* Formatting instructions */
     ODR stream;                /* encoding stream - memory source if required */
@@ -161,12 +90,12 @@ typedef struct {
     char *errstring;           /* system error string or NULL */
 } bend_present_rr;
 
+/** \brief Information for fetch record handler */
 typedef struct bend_fetch_rr {
     char *setname;             /* set name */
     int number;                /* record number */
     Z_ReferenceId *referenceId;/* reference ID */
-    oid_value request_format;  /* One of the CLASS_RECSYN members */
-    int *request_format_raw;   /* same as above (raw OID) */
+    Odr_oid *request_format;        /* format, transfer syntax (OID) */
     Z_RecordComposition *comp; /* Formatting instructions */
     ODR stream;                /* encoding stream - memory source if req */
     ODR print;                 /* printing stream */
@@ -175,18 +104,20 @@ typedef struct bend_fetch_rr {
     int len;                   /* length of record or -1 if structured */
     char *record;              /* record */
     int last_in_set;           /* is it?  */
-    oid_value output_format;   /* format */
-    int *output_format_raw;    /* used instead of above if not-null */
+    Odr_oid *output_format;        /* response format/syntax (OID) */
     int errcode;               /* 0==success */
     char *errstring;           /* system error string or NULL */
     int surrogate_flag;        /* surrogate diagnostic */
+    char *schema;              /* string record schema input/output */
 } bend_fetch_rr;
 
+/** \brief Information for scan entry */
 struct scan_entry {
     char *term;         /* the returned scan term */
-    int occurrences;    /* no of occurrences or -1 if error (see below) */
+    Odr_int occurrences;/* no of occurrences or -1 if error (see below) */
     int errcode;        /* Bib-1 diagnostic code; only used when occur.= -1 */
     char *errstring;    /* Additional string */
+    char *display_term;
 };
 
 typedef enum {
@@ -194,38 +125,66 @@ typedef enum {
     BEND_SCAN_PARTIAL   /* not all entries could be found */
 } bend_scan_status;
 
+/** \brief Information for SRU / Z39.50 scan handler */
 typedef struct bend_scan_rr {
     int num_bases;      /* number of elements in databaselist */
     char **basenames;   /* databases to search */
-    oid_value attributeset;
+    Odr_oid *attributeset;
     Z_ReferenceId *referenceId; /* reference ID */
     Z_AttributesPlusTerm *term;
     ODR stream;         /* encoding stream - memory source if required */
     ODR print;          /* printing stream */
 
-    int *step_size;     /* step size */
-    int term_position;  /* desired index of term in result list/returned */
+    Odr_int *step_size;     /* step size */
+    Odr_int term_position;  /* desired index of term in result list/returned */
     int num_entries;    /* number of entries requested/returned */
 
+    /* scan term entries. The called handler does not have
+       to allocate this. Size of entries is num_entries (see above) */
     struct scan_entry *entries;
     bend_scan_status status;
     int errcode;
     char *errstring;
+    char *scanClause;   /* CQL scan clause */
+    char *setname;      /* Scan in result set (NULL if omitted) */
 } bend_scan_rr;
 
-/* delete handler */
+/** \brief Information for SRU record update handler */
+typedef struct bend_update_rr {
+    int num_bases;      /* number of elements in databaselist */
+    char **basenames;   /* databases to search */
+    Z_ReferenceId *referenceId; /* reference ID */
+    ODR stream;         /* encoding stream - memory source if required */
+    ODR print;          /* printing stream */
+    char *operation;
+    char *operation_status;
+    char *record_id;
+    Z_SRW_recordVersion *record_versions;
+    int num_versions;
+    char *record_packing;
+    char *record_schema;
+    char *record_data;
+    char *extra_record_data;
+    char *extra_request_data;
+    char *extra_response_data;
+    char *uri;
+    char *message;
+    char *details;
+} bend_update_rr;
+
+/** \brief Information for Z39.50 delete result set handler */
 typedef struct bend_delete_rr {
     int function;
     int num_setnames;
     char **setnames;
     Z_ReferenceId *referenceId;
-    int delete_status;      /* status for the whole operation */
-    int *statuses;          /* status each set - indexed as setnames */
+    int delete_status;    /* status for the whole operation */
+    Odr_int *statuses;    /* status each set - indexed as setnames */
     ODR stream;
     ODR print; 
 } bend_delete_rr;
 
-/* sort handler */
+/** \brief Information for Z39.50 sort handler */
 typedef struct bend_sort_rr
 {
     int num_input_setnames;
@@ -241,6 +200,7 @@ typedef struct bend_sort_rr
     char *errstring;
 } bend_sort_rr;
 
+/** \brief Information for Z39.50 extended services handler */
 typedef struct bend_esrequest_rr
 {
     int ItemNo;
@@ -257,6 +217,7 @@ typedef struct bend_esrequest_rr
     Z_TaskPackage *taskPackage;
 } bend_esrequest_rr;
 
+/** \brief Information for Z39.50 segment handler */
 typedef struct bend_segment_rr {
     Z_Segment *segment;
     ODR stream;
@@ -266,27 +227,92 @@ typedef struct bend_segment_rr {
     bend_association association;
 } bend_segment_rr;
 
+/** \brief Information for SRU Explain handler */
+typedef struct {
+    ODR stream;
+    ODR decode;
+    ODR print;
+    char *explain_buf;
+    char *database;
+    char *schema;
+    void *server_node_ptr;
+} bend_explain_rr;
+
+/** \brief Information for the Init handler
+
+This includes both request
+information (to be read) and response information which should be
+set by the bend_init handler 
+*/
 typedef struct bend_initrequest
 {
-    Z_IdAuthentication *auth;
-    ODR stream;                /* encoding stream */
-    ODR print;                 /* printing stream */
-    Z_ReferenceId *referenceId;/* reference ID */
-    char *peer_name;           /* dns host of peer (client) */
+    /** \brief user/name/password to be read */
+    Z_IdAuthentication *auth; 
+    /** \brief encoding stream (for results) */
+    ODR stream;
+    /** \brief printing stream */
+    ODR print;
+    /** \brief decoding stream (use stream for results) */
+    ODR decode; 
+    /** \brief reference ID */
+    Z_ReferenceId *referenceId;
+    /** \brief peer address of client */
+    char *peer_name;           
     
+    /** \brief character set and language negotiation 
+
+    see include/yaz/z-charneg.h 
+    */
+    Z_CharSetandLanguageNegotiation *charneg_request;
+
+    /** \brief character negotiation response */
+    Z_External *charneg_response;
+
+    /** \brief character set (encoding) for query terms 
+        
+    This is NULL by default. It should be set to the native character
+    set that the backend assumes for query terms */
+    char *query_charset;      
+
+    /** \brief whehter query_charset also applies to recors 
+    
+    Is 0 (No) by default. Set to 1 (yes) if records is in the same
+    character set as queries. If in doubt, use 0 (No).
+    */
+    int records_in_same_charset;
+
     char *implementation_id;
     char *implementation_name;
     char *implementation_version;
-    int (*bend_sort) (void *handle, bend_sort_rr *rr);
-    int (*bend_search) (void *handle, bend_search_rr *rr);
-    int (*bend_fetch) (void *handle, bend_fetch_rr *rr);
-    int (*bend_present) (void *handle, bend_present_rr *rr);
+
+    /** \brief Z39.50 sort handler */
+    int (*bend_sort)(void *handle, bend_sort_rr *rr);
+    /** \brief SRU/Z39.50 search handler */
+    int (*bend_search)(void *handle, bend_search_rr *rr);
+    /** \brief SRU/Z39.50 fetch handler */
+    int (*bend_fetch)(void *handle, bend_fetch_rr *rr);
+    /** \brief SRU/Z39.50 present handler */
+    int (*bend_present)(void *handle, bend_present_rr *rr);
+    /** \brief Z39.50 extended services handler */
     int (*bend_esrequest) (void *handle, bend_esrequest_rr *rr);
+    /** \brief Z39.50 delete result set handler */
     int (*bend_delete)(void *handle, bend_delete_rr *rr);
+    /** \brief Z39.50 scan handler */
     int (*bend_scan)(void *handle, bend_scan_rr *rr);
+    /** \brief Z39.50 segment facility handler */
     int (*bend_segment)(void *handle, bend_segment_rr *rr);
+    /** \brief SRU explain handler */
+    int (*bend_explain)(void *handle, bend_explain_rr *rr);
+    /** \brief SRU scan handler */
+    int (*bend_srw_scan)(void *handle, bend_scan_rr *rr);
+    /** \brief SRU record update handler */
+    int (*bend_srw_update)(void *handle, bend_update_rr *rr);
+
+    /** \brief whether named result sets are supported (0=disable, 1=enable) */
+    int named_result_sets;
 } bend_initrequest;
 
+/** \brief result for init handler (must be filled by handler) */
 typedef struct bend_initresult
 {
     int errcode;               /* 0==OK */
@@ -295,7 +321,7 @@ typedef struct bend_initresult
 } bend_initresult;
 
 YAZ_EXPORT void bend_request_send (bend_association a, bend_request req,
-				   Z_APDU *res);
+                                   Z_APDU *res);
 
 YAZ_EXPORT bend_request bend_request_mk (bend_association a);
 
@@ -306,16 +332,16 @@ YAZ_EXPORT int bend_backend_respond (bend_association a, bend_request req);
 YAZ_EXPORT void bend_request_setdata(bend_request r, void *p);
 YAZ_EXPORT void *bend_request_getdata(bend_request r);
 
+/** \brief control block for server */
 typedef struct statserv_options_block
 {
     int dynamic;                  /* fork on incoming requests */
     int threads;                  /* use threads */
     int one_shot;                 /* one session then exit(1) */
-    int loglevel;                 /* desired logging-level */
     char apdufile[ODR_MAXNAME+1]; /* file for pretty-printed PDUs */
     char logfile[ODR_MAXNAME+1];  /* file for diagnostic output */
     char default_listen[1024];    /* 0 == no default listen */
-    enum oid_proto default_proto; /* PROTO_SR or PROTO_Z3950 */
+    enum oid_proto default_proto; /* PROTO_SR or PROTO_Z3950 */ 
     int idle_timeout;             /* how many minutes to wait before closing */
     int maxrecordsize;            /* maximum value for negotiation */
     char configname[ODR_MAXNAME+1];  /* given to the backend in bend_init */
@@ -338,18 +364,32 @@ typedef struct statserv_options_block
     char service_dependencies[128]; /* The services we are dependent on */
     char service_display_name[128]; /* The service display name */
 #endif /* WIN32 */
+    struct bend_soap_handler *soap_handlers;
+    char pid_fname[128];            /* pid fname */
+    int background;                 /* auto daemon */
+    char cert_fname[128];           /* SSL certificate fname */
+    char xml_config[128];           /* XML config filename */
 } statserv_options_block;
 
 YAZ_EXPORT int statserv_main(
     int argc, char **argv,
     bend_initresult *(*bend_init)(bend_initrequest *r),
     void (*bend_close)(void *handle));
-YAZ_EXPORT int statserv_start(int argc, char **argv);
-YAZ_EXPORT void statserv_closedown(void);
 YAZ_EXPORT statserv_options_block *statserv_getcontrol(void);
 YAZ_EXPORT void statserv_setcontrol(statserv_options_block *block);
 YAZ_EXPORT int check_ip_tcpd(void *cd, const char *addr, int len, int type);
 
+YAZ_EXPORT int bend_assoc_is_alive(bend_association assoc);
+
 YAZ_END_CDECL
 
 #endif
+/*
+ * Local variables:
+ * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
+ * indent-tabs-mode: nil
+ * End:
+ * vim: shiftwidth=4 tabstop=8 expandtab
+ */
+
